@@ -4,7 +4,7 @@ f  ice-9/hash-table.scm	g  exportsS	g  alist->hash-table
 g  alist->hashq-table	g  alist->hashv-table	g  alist->hashx-table	
  	g  set-current-module	 	 	g  make-syntax-transformer	 	 	g  define-alist-converter	g  macro	g  $sc-dispatch	 	 	g  any	 	g  
 syntax-object	g  define	 g  top	!  	"g  ribcage	#g  dummy	$g  name	%g  
-hash-set-proc	&#$% 	'g  m-Ksr$Rx9gqmjcnhSS9xweki-9542	('  	)(!! 	*f  l-Ksr$Rx9gqmjcnhSS9xweki-9547	+f  l-Ksr$Rx9gqmjcnhSS9xweki-9548	,f  l-Ksr$Rx9gqmjcnhSS9xweki-9549	-*+, 	."&)- 	/" 	0g  x	10 	2( 	3f  l-Ksr$Rx9gqmjcnhSS9xweki-9544	43 	5"124 	6!./5 	7g  hygiene	87 	968 	:g  alist	;:68 	<; 	=f   Convert ALIST into a hash table.	>=68 	?g  let	@?68 	Ag  table	BA68 	Cg  make-hash-table	DC68 	ED 	FBE 	GF 	Hg  for-each	IH68 	Jg  lambda	KJ68 	Lg  pair	ML68 	NM 	Og  car	PO68 	QPM 	Rg  cdr	SR68 	TSM 	UBQT 	Vg  reverse	WV68 	XW; 	YX 	ZB 	[g  syntax-violation	\[ 	][ 	^f  -source expression failed to match any pattern	_g  	hash-set!	`g  
+hash-set-proc	&#$% 	'g  m-emh6F@ZQOIVvy2FL7q3q6J-9585	('  	)(!! 	*f  l-emh6F@ZQOIVvy2FL7q3q6J-9590	+f  l-emh6F@ZQOIVvy2FL7q3q6J-9591	,f  l-emh6F@ZQOIVvy2FL7q3q6J-9592	-*+, 	."&)- 	/" 	0g  x	10 	2( 	3f  l-emh6F@ZQOIVvy2FL7q3q6J-9587	43 	5"124 	6!./5 	7g  hygiene	87 	968 	:g  alist	;:68 	<; 	=f   Convert ALIST into a hash table.	>=68 	?g  let	@?68 	Ag  table	BA68 	Cg  make-hash-table	DC68 	ED 	FBE 	GF 	Hg  for-each	IH68 	Jg  lambda	KJ68 	Lg  pair	ML68 	NM 	Og  car	PO68 	QPM 	Rg  cdr	SR68 	TSM 	UBQT 	Vg  reverse	WV68 	XW; 	YX 	ZB 	[g  syntax-violation	\[ 	][ 	^f  -source expression failed to match any pattern	_g  	hash-set!	`g  
 hashq-set!	ag  
 hashv-set!	bg  
 hashx-set!C 5    hx  x   ]4	
