@@ -22,7 +22,7 @@ re-exportsS	gg  cons	hg  list	ig  cons*	jg  	make-list	kg  pair?	lg  
 list-index g  member g  delete g  delete! g  assoc  
  g  set-current-module     g  cond-expand-provide g  current-module   g  load-extension g  
 string-append f  	libguile- g  effective-version f  scm_init_srfi_1 g  	scm-error g  wrong-type-arg g  symbol->string f  Wrong type argument: ~S g  make-syntax-transformer     g  	check-arg g  macro g  $sc-dispatch     PPPP  g  
-syntax-object g  if g  top   g  ribcage g  dummy g  pred g  arg g  caller   g  m-mq$vSOmzwtMvLNbYZMxluO-116166     f  l-mq$vSOmzwtMvLNbYZMxluO-116171 f  l-mq$vSOmzwtMvLNbYZMxluO-116172 f  l-mq$vSOmzwtMvLNbYZMxluO-116173 f  l-mq$vSOmzwtMvLNbYZMxluO-116174       g  x     f  l-mq$vSOmzwtMvLNbYZMxluO-116168       g  hygiene     g  not     g  quote   g  syntax-violation     f  -source expression failed to match any pattern g  out-of-range f  Value out of range: ~A g  integer? g  non-negative-integer? g  error f  not a proper list in null-list? g  
+syntax-object g  if g  top   g  ribcage g  dummy g  pred g  arg g  caller   g  m-OS20ZLkLXiTZOrqMDD8Wc7-116316     f  l-OS20ZLkLXiTZOrqMDD8Wc7-116321 f  l-OS20ZLkLXiTZOrqMDD8Wc7-116322 f  l-OS20ZLkLXiTZOrqMDD8Wc7-116323 f  l-OS20ZLkLXiTZOrqMDD8Wc7-116324       g  x     f  l-OS20ZLkLXiTZOrqMDD8Wc7-116318       g  hygiene     g  not     g  quote   g  syntax-violation     f  -source expression failed to match any pattern g  out-of-range f  Value out of range: ~A g  integer? g  non-negative-integer? g  error f  not a proper list in null-list? g  
 procedure? g  	list-head g  	list-tail g  any1 f  map f  Circular list: ~S f  Not a list: ~S g  min f  .Args do not contain a proper (finite) list: ~S f  for-each g  apply g  every1 g  acons g  equal? g  eq? g  eqv?C 5     h    ]4	
 ef5	 4 >  "  G   4i4i5 >  "  G  4i4i4i5 5>  "  G         h      ] C       g  d
 		 g  a		  g  filenamef  srfi/srfi-1.scm
@@ -146,17 +146,12 @@ documentationf  3Return two values, the `car' and the `cdr' of PAIR. C Ri!
 q
 	r			s		
 s		t		t		t		r		!r		1r	 		1	  g  nameg  
-take-right C#R    h       ]$   4L  5CC            g  lag
-		 g  lead		  g  filenamef  srfi/srfi-1.scm
-x		y			y		z		
-z		z		z	)	z		z		{	 			  g  nameg  recur C" h       ]
-O Q  4 56         g  lis
-		 g  k		 g  recur		
-	  g  filenamef  srfi/srfi-1.scm
+take-right C#R"       h@   &  ]"  #$  "6 4 5"       g  lis
+		? g  k		? g  lag			) g  lead			) g  result			)  g  filenamef  srfi/srfi-1.scm
 w
-	
-x		x		x	 			  g  nameg  
-drop-right C$R"       h      ]
+	x			y		
+y		z		z		z	'	z	!	#z		){		)x		,x		5x	1	?x	 		?	  g  nameg  
+drop-right C$R" h      ]
 
 $  C4 5 C       g  lst
 		 g  i		 g  tail			  g  filenamef  srfi/srfi-1.scm
@@ -273,40 +268,40 @@ g  filenamef  srfi/srfi-1.scm
 documentationf  `reduce' is a variant of `fold', where the first call to F is on two
 elements from LST, rather than one element and a given initial value.
 If LST is empty, RIDENTITY is returned.  If LST has just one element
-then that's the return value. C:R:7)$        hH     ]4 5$  "  4 >  "  G  (  C 45456           g  f
-		C g  	ridentity		C g  lst			C  g  filenamef  srfi/srfi-1.scm
+then that's the return value. C:R:        h     ] 456             g  f
+		 g  	ridentity		 g  lst			  g  filenamef  srfi/srfi-1.scm
 *
-	/		+0		32		:2		C2	 		C	  g  nameg  reduce-rightg  
+		/		/	 			  g  nameg  reduce-rightg  
 documentationf  `reduce-right' is a variant of `fold-right', where the first call to
 F is on two elements from LST, rather than one element and a given
 initial value.  If LST is empty, RIDENTITY is returned.  If LST
-has just one element then that's the return value. C;R6*        h(      ]
+has just one element then that's the return value. C;R6*   h(      ]
 4 5$  $  6CC          g  ls
 		% g  len		% g  ls-len				%  g  filenamef  srfi/srfi-1.scm
-I		J	&		J		K		L		L	) 		%	   C*nm     h    )   3 4 5$  "  4 >  "  G  "  |$  Y$  6&   64 5"4 5"(  6	 6"r- 1 3 4 5$  "  4 >  "  G  4
+F		G	&		G		H		I		I	) 		%	   C*nm     h    )   3 4 5$  "  4 >  "  G  "  |$  Y$  6&   64 5"4 5"(  6	 6"r- 1 3 4 5$  "  4 >  "  G  4
 455$  "  4
  >  "  G  "  =
 $  6454 45?""             g  f
 		  g  l		  g  hare		0  g  tortoise		0  g  move?		0  g  out		0  g  f
  y g  l1 y g  rest	 y g  len	 y g  l1	)f g  rest	)f g  len	)f g  out	)f  g  filenamef  srfi/srfi-1.scm
-5		
-7		08		39		79		=:		E;		I<		K<	.	M<	4	R=		U<		X>		[>	$	]?		b?	 	d?		g?		s>		v@		zA		A	 A	 A	 @	 B	 C	 D	 D	* D	0 E	 D	 8	 8	6 8	 5	 H	 I	 N	 I	 I	P	Q	Q	
-Q	&R	S	S	Q	)T	,U	
-1U		7V	
-:W	;W	FW	+GX	LX	"MX	+WX	ZX	fW	
-fT	mT	5yT	 B		 	  y	
+2		
+4		05		36		76		=7		E8		I9		K9	.	M9	4	R:		U9		X;		[;	$	]<		b<	 	d<		g<		s;		v=		z>		>	 >	 >	 =	 ?	 @	 A	 A	* A	0 B	 A	 5	 5	6 5	 2	 E	 F	 K	 F	 F	M	N	N	
+N	&O	P	P	N	)Q	,R	
+1R		7S	
+:T	;T	FT	+GU	LU	"MU	+WU	ZU	fT	
+fQ	mQ	5yQ	 B		 	  y	
 	  g  nameg  map CRiR6* h(      ]
 4 5$  $  6CC          g  ls
 		% g  len		% g  ls-len				%  g  filenamef  srfi/srfi-1.scm
-s		t	&		t		u		v		v	) 		%	   C*mn   h  Z  )   3 4 5$  "  4 >  "  G  "  $  e$  <&   64 >  "  G  "4 >  "  G  "(  C 6"m- 1 3 4 5$  "  4 >  "  G  4	
+p		q	&		q		r		s		s	) 		%	   C*mn   h  Z  )   3 4 5$  "  4 >  "  G  "  $  e$  <&   64 >  "  G  "4 >  "  G  "(  C 6"m- 1 3 4 5$  "  4 >  "  G  4	
 455$  "  4 >  "  G  "  A
 $  74
  45>  "  G  45"C" R      g  f
 		  g  l		  g  hare		0  g  tortoise		0  g  move?		0  g  f
   g  l1  g  rest	  g  len	  g  l1	.o g  rest	.o g  len	.o  g  filenamef  srfi/srfi-1.scm
-]		
-_		0`		3a		7a		=b		Ec		Id		Kd	.	Md	9	Re		Ud		Vg		[g		`g		kh	 	nh	+	yh		zj		j	 j	 k	 k	 m	 n	 n	* n	5 o	 n	 `	 ]	 r	 s	 x	 s	 s	z	{	{	{	&|	}	}	"{	.~	2	
-6		7	>	?	!L	W	X	#c	2m	o~	 9		 	  	
+Z		
+\		0]		3^		7^		=_		E`		Ia		Ka	.	Ma	9	Rb		Ua		Vd		[d		`d		ke	 	ne	+	ye		zg		g	 g	 h	 h	 j	 k	 k	* k	5 l	 k	 ]	 Z	 o	 p	 u	 p	 p	w	x	x	x	&y	z	z	"x	.{	2|	
+6|		7~	>~	?~	!L~	W	X	#c	2m	o{	 9		 	  	
 	  g  nameg  for-each CR+   h      - 1 3 4 ?6       g  f
 			 g  clist1			 g  rest				  g  filenamef  srfi/srfi-1.scm
 
@@ -374,86 +369,85 @@ all satisfy the predicate PRED, and the remainder of LST. CLRM        h
 documentationf   Linear-update variant of `span'. CMRN   hh     ]4 5$  "  4 >  "  G  "  3(  "  4 5$  45D""       g  pred
 		g g  clist		g g  clist		)	\ g  rl		)	\  g  filenamef  srfi/srfi-1.scm
 
-			)		/ 		0 		5		:		<		@ 		A		K		N		Q		T		\		\		_		g	 		g	  g  nameg  breakg  
+			)		/		0		5		:		<		@		A		K		N 		Q 		T 		\ 		\		_		g	 		g	  g  nameg  breakg  
 documentationf  zReturn two values, the longest initial prefix of LST whose elements
 all fail the predicate PRED, and the remainder of LST. CNRO     hp   }  ]4 5$  "  4 >  "  G  "  :(  D4 5$  $  
 DD""  u      g  pred
 		n g  list		n g  l		)	c g  prev		)	c  g  filenamef  srfi/srfi-1.scm
-
-			)		/
-		2		4		5		:		<		@
-		C
+
+			)		/		2		4		5			:			<			@		C
 		G
-		J	 	K		Q		R		V		Y		c		c	 		n	  g  nameg  break!g  
+		J	 	K		Q
+		R		V		Y		c		c	 		n	  g  nameg  break!g  
 documentationf  !Linear-update variant of `break'. CORPlnm 	   h   u  - 1 3 4 5$  "  4 >  "  G  (   6"  X45$  C4455$  
  45@4 45?$  C45""       m      g  pred
 		  g  ls		  g  lists			  g  lists		>  g  t		|   g  filenamef  srfi/srfi-1.scm
-
+
 	
-		2		:		>		?		K		N		S		]		a		d		n		o		r		|		|	 	4 	0 	 	 	 		 	
+		2		:		>		?		K		N		S		]		a		d		n		o		r		|		|	 	4 	0 	 	 	 		 	
 	  g  nameg  any CPR      h@   
   ]"  2(  C(   64 5$  C""      g  pred
 		@ g  ls		@ g  ls			8 g  t		$	8  g  filenamef  srfi/srfi-1.scm
-!
-	"		#		%		#		&		&		(		"(		$(		$(		2(	#	8(		8"	 		@	  g  nameg  any1 CRQlnm 
+
+			 		"		 		#		#		%		"%		$%		$%		2%	#	8%		8	 		@	  g  nameg  any1 CRQlnm 
     h   h  - 1 3 4 5$  "  4 >  "  G  (   6"  S45$  C4455$  
  4	5@4 4	5?$  45"C"    `      g  pred
 		  g  ls		  g  lists			  g  lists		>   g  filenamef  srfi/srfi-1.scm
-*
+'
 	
-+		2,		:-		>.		?/		K/		N1		S1		]1		a/		d2		n2		o4		r4	 	|4	 4	 4	5 4	1 .	 .	 .	 		 	
+(		2)		:*		>+		?,		K,		N.		S.		].		a,		d/		n/		o1		r1	 	|1	 1	 1	5 1	1 +	 +	 +	 		 	
 	  g  nameg  every CQR   h@      ]
 "  -(  C(   64 5$  	"C"            g  pred
 		; g  ls		; g  ls			3  g  filenamef  srfi/srfi-1.scm
-6
-	7		8		:		8		;		;		=		"=		$=		(=		+=	$	1=	 	37	 		;	  g  nameg  every1 CRlmn 	   h   A  - 1 3 4 5$  "  4 >  "  G  (  4"  %(  C4 5$  C"
+3
+	4		5		7		5		8		8		:		":		$:		(:		+:	$	1:	 	34	 		;	  g  nameg  every1 CRlmn 	   h   A  - 1 3 4 5$  "  4 >  "  G  (  4"  %(  C4 5$  C"
 ""  845$  C4 45?$  C45"
 "9      g  pred
 		  g  clist1		  g  rest			  g  l		6	[ g  i		6	[ g  lists		j  g  i		j   g  filenamef  srfi/srfi-1.scm
-?
+<
 	
-B		2C		6D		<E		?G		DG		FG		JG		PI		SI		[I	
-	[D		jJ		kK	
-	wK		zM	
-	}M	 M	
- K	 O	 O	! O	
- J	 J	 J	 		 	
+?		2@		6A		<B		?D		DD		FD		JD		PF		SF		[F	
+	[A		jG		kH	
+	wH		zJ	
+	}J	 J	
+ H	 L	 L	! L	
+ G	 G	 G	 		 	
 	  g  nameg  
 list-indexg  
 documentationf  gReturn the index of the first set of elements, one from each of
 CLIST1 ... CLISTN, that satisfies PRED. CRiTRT     h8   r  ]"  &(  645" " j      g  alist
 		7 g  a		, g  rl			,  g  filenamef  srfi/srfi-1.scm
-U
-	X		Z		[		\		\		\	 	\	)	$\		,\		,X		/Y		7X	 		7  g  nameg  
+R
+	U		W		X		Y		Y		Y	 	Y	)	$Y		,Y		,U		/V		7U	 		7  g  nameg  
 alist-copyg  
 documentationf  eReturn a copy of ALIST, copying both the pairs comprising the list
 and those making the associations. CURV     h   N  - . , 3 #  45$  "  4>  "  G  "  9(  64 5$  
 """       F      g  key
 	  g  alist	  g  k=		  g  a		=	v g  rl		=	v  g  filenamef  srfi/srfi-1.scm
-^
-	_		=`		Ca		Ib		Jc		Qc		Tc		Xc		[d		ed		he		ke		ne		ve		v`		y`	 `	 	 	  g  nameg  alist-delete CVRV       h       - . , 3 #   6       g  key
+[
+	\		=]		C^		I_		J`		Q`		T`		X`		[a		ea		hb		kb		nb		vb		v]		y]	 ]	 	 	  g  nameg  alist-delete CVRV       h       - . , 3 #   6       g  key
 		  g  alist		  g  k=			   g  filenamef  srfi/srfi-1.scm
-g
-	 h	 		 	  g  nameg  
+d
+	 e	 		 	  g  nameg  
 alist-delete! CWRH     h   \   ]LL  6      T       g  y
 		
   g  filenamef  srfi/srfi-1.scm
-t		
-t	 		
+q		
+q	 		
    C hh      - . , 3 #  &   6&   645$  "  4>  "  G  	
  O 6       g  x
 		h g  ls		h g  =			h  g  filenamef  srfi/srfi-1.scm
-l
-	m		&p		.m		6q		7s		ht	 		h	  g  nameg  member CRXQ   h   f   ] LL 6   ^       g  el
+i
+	j		&m		.j		6n		7p		hq	 		h	  g  nameg  member CRXQ   h   f   ] LL 6   ^       g  el
 		
   g  filenamef  srfi/srfi-1.scm
-~			~	0	
-~	% 		
+{			{	0	
+{	% 		
    C       hx     - 1 3 4 5$  "  4 >  "  G  (  C"  ,(  C4 O 5$  "C"            g  =
 			r g  rest			r g  f		8	d g  r		8	d  g  filenamef  srfi/srfi-1.scm
-x
+u
 	
-y		2z		8|		>}		?}		A~		T~		W		Z		b		d|		g|		j|	!	r|	 			r
+v		2w		8y		>z		?z		A{		T{		W|		Z|		b|		dy		gy		jy	!	ry	 			r
   g  nameg  lset<= CXRXQ  h   f   ] LL 6   ^       g  el
 		
   g  filenamef  srfi/srfi-1.scm
@@ -469,9 +463,9 @@ alist-delete! CWRH     h   \   ]LL  6      T       g  y
 		  g  filenamef  srfi/srfi-1.scm
 			# 		   C        h   <  - 1 3 4 5$  "  4 >  "  G  (  C"  C(  C4 O 5$  %4 O 5$  "CC"       4      g  =
 		  g  rest		  g  f		8	{ g  r		8	{  g  filenamef  srfi/srfi-1.scm
-
+~
 	
-		2		8		>		?	
+		2		8		>		?	
 	A		T	
 	U		c	I	e		i	
 	l		o		w		{		~	 	 	 		 
@@ -581,7 +575,7 @@ lset-union C[R\Q       h   f   ]L L 6   ^       g  ll
 			6 g  list1			6 g  rest				6  g  filenamef  srfi/srfi-1.scm
 
 	
- 		6	 			6	
+		6	 			6	
 	  g  nameg  lset-diff+intersection! CdRC         g  m
 		0  g  filenamef  srfi/srfi-1.scm		'
 	1 
@@ -618,60 +612,60 @@ lset-union C[R\Q       h   f   ]L L 6   ^       g  ll
 k
 q
 w
-}
+}
 
-!
-#+
-$
+ 
+"
+#
+%9
 %
-&)
 &
-'
-(u
-)f
-,
-/
-2
-5
-9}
-;
-= 
-?*
-FU4
-F\Z
-LE\
-M
-M
-M
-Q
-T
-V
-X
-Z
-\
-^
-a!
-c(
-eh
-f!
-h*
-j@6
-mT?
-m[S
-oU
-q^
-qg
-sl
-ux
-yW
-}}
+'D
+(
+)
+,z
+/]
+2*
+5s
+9%
+;B
+=X 
+?@*
+E1
+EW
+KY
+Lg
+M8
+M?
+QD
+Si
+V*
+X
+Y
+\
+^)
+`q
+bx
+d
+f
+hC'
+i3
+l<
+lP
+nmR
+pa[
+q6d
+ri
+u'u
+x~
+|
+      
       
+      
+      @
       2
-      
-      
-      
-      
-      
+      
+      
       
       
  a	      
